@@ -30,7 +30,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
+#include <gio/gio.h>
 
 #include "gtksecentry.h"
 #include "secmem-util.h"
@@ -39,8 +39,8 @@
 #include "krb5-auth-dialog.h"
 #include "krb5-auth-applet.h"
 #include "krb5-auth-pwdialog.h"
-#include "krb5-auth-gconf.h"
 #include "krb5-auth-dbus.h"
+#include "krb5-auth-tools.h"
 
 #ifdef ENABLE_NETWORK_MANAGER
 #include <libnm_glib.h>
@@ -135,7 +135,7 @@ get_principal_realm_data(krb5_principal p)
 }
 
 static const char*
-get_error_message(krb5_context context, krb5_error_code err)
+ka_get_error_message(krb5_context context, krb5_error_code err)
 {
 	const char *msg = NULL;
 
@@ -366,7 +366,7 @@ credentials_expiring (gpointer *data)
 				retval = grab_credentials (applet);
 				give_up = canceled &&
 					  (creds_expiry == canceled_creds_expiry);
-			} while ((retval != 0) && 
+			} while ((retval != 0) &&
 			         (retval != KRB5_REALM_CANT_RESOLVE) &&
 			         (retval != KRB5_KDC_UNREACH) &&
 				 invalid_auth &&
@@ -653,7 +653,7 @@ grab_credentials (KaApplet* applet)
 				break;
 			default:
 				KA_DEBUG("Auth failed with %d: %s", retval,
-				         get_error_message(kcontext, retval));
+				         ka_get_error_message(kcontext, retval));
 				break;
 		}
 		goto out;
@@ -708,12 +708,12 @@ ka_renew_credentials (KaApplet* applet)
 
 		retval = krb5_cc_initialize(kcontext, ccache, kprincipal);
 		if(retval) {
-			g_warning("krb5_cc_initialize: %s", get_error_message(kcontext, retval));
+			g_warning("krb5_cc_initialize: %s", ka_get_error_message(kcontext, retval));
 			goto out;
 		}
 		retval = krb5_cc_store_cred(kcontext, ccache, &my_creds);
 		if (retval) {
-			g_warning("krb5_cc_store_cred: %s", get_error_message(kcontext, retval));
+			g_warning("krb5_cc_store_cred: %s", ka_get_error_message(kcontext, retval));
 			goto out;
 		}
 	}
@@ -785,11 +785,9 @@ using_krb5(void)
 }
 
 
-void
-ka_destroy_cache (GtkMenuItem  *menuitem G_GNUC_UNUSED,
-		  gpointer data)
+gboolean
+ka_destroy_ccache (KaApplet *applet)
 {
-	KaApplet *applet = KA_APPLET(data);
 	krb5_ccache  ccache;
 	const char* cache;
 	krb5_error_code ret;
@@ -799,20 +797,11 @@ ka_destroy_cache (GtkMenuItem  *menuitem G_GNUC_UNUSED,
 	ret = krb5_cc_destroy (kcontext, ccache);
 
 	credentials_expiring_real(applet);
-}
 
-
-static void
-ka_error_dialog(int err)
-{
-	const char* msg = get_error_message(kcontext, err);
-	GtkWidget *dialog = gtk_message_dialog_new (NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_CLOSE,
-				_("Couldn't acquire kerberos ticket: '%s'"), msg);
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
+	if (ret)
+		return FALSE;
+	else
+		return TRUE;
 }
 
 
@@ -881,7 +870,9 @@ ka_grab_credentials (KaApplet* applet)
 		if (canceled)
 			break;
 		if (retval) {
-			ka_error_dialog(retval);
+			ka_pwdialog_error(pwdialog,
+					  ka_get_error_message(kcontext,
+                                                               retval));
 			break;
 		} else {
 			success = TRUE;
@@ -934,36 +925,12 @@ ka_nm_init(void)
 }
 
 
-static GtkWidget*
-ka_create_gtk_secure_entry (GladeXML *xml G_GNUC_UNUSED,
-			    gchar *func_name G_GNUC_UNUSED,
-			    gchar *name,
-			    gchar *s1 G_GNUC_UNUSED,
-			    gchar *s2 G_GNUC_UNUSED,
-			    gint i1 G_GNUC_UNUSED,
-			    gint i2 G_GNUC_UNUSED,
-			    gpointer user_data G_GNUC_UNUSED)
-{
-	GtkWidget* entry = NULL;
-
-	if (!strcmp(name, "krb5_entry")) {
-		entry = gtk_secure_entry_new ();
-		gtk_secure_entry_set_activates_default(GTK_SECURE_ENTRY(entry), TRUE);
-		gtk_widget_show (entry);
-	} else {
-		g_warning("Don't know anything about widget %s", name);
-	}
-	return entry;
-}
-
-
 int
 main (int argc, char *argv[])
 {
 	KaApplet *applet;
 	GOptionContext *context;
 	GError *error = NULL;
-	GladeXML *xml;
 
 	guint status = 0;
 	gboolean run_auto = FALSE, run_always = FALSE;
@@ -1000,16 +967,11 @@ main (int argc, char *argv[])
 		always_run = TRUE;
 	}
 	if (using_krb5 () || always_run) {
-		g_set_application_name (_("Network Authentication"));
+		g_set_application_name (KA_NAME);
 
-		glade_set_custom_handler (&ka_create_gtk_secure_entry, NULL);
-		xml = glade_xml_new (KA_DATA_DIR G_DIR_SEPARATOR_S
-				     PACKAGE ".glade", NULL, NULL);
-		applet = ka_applet_create (xml);
+		applet = ka_applet_create ();
 		if (!applet)
 			return 1;
-		if (!ka_gconf_init (applet, argc, argv))
-			return 1;
 		ka_nm_init();
 
 		if (credentials_expiring ((gpointer)applet)) {
@@ -1018,7 +980,6 @@ main (int argc, char *argv[])
 		}
 		ka_dbus_service(applet);
 		gtk_main ();
-		g_object_unref(xml);
 	}
 	return 0;
 }
